# Changelog

<!--next-version-placeholder-->

## v0.2.0 (25/07/2022)
- Add push-based algorithm for solving the $\psi$-score problem. Written by Maximilien Danisch and Anastasios Giovanidis
- Possibility to get the $\mathbf{p}_i$ and $\mathbf{q}_i$ vectors with Push and Power-NF

## v0.1.0 (13/07/2022)

- First release of `psi-score`!